% arxiv2009_SFA2_images
% script for producing the images and the table data in 
% Konen, W. (2009), 
% "On the numeric stability of the SFA implementation sfa-tk",
% http://arxiv.org/abs/cond-mat/????. 
%
% You need to activate the line
%    gam = (0*sin(nuf*0.0047*t) + sin(nuf*0.0005*t))/2;     % activate this line for arxiv2009_SFA2.m
% in function drive1.m

function res = arxiv2009_SFA2(noiseperc)
    global SFA_STRUCTS

    tau=1;
    nuf=25;
    q=1.2;
    dographics=2;
    if nargin<1, noiseperc=0; end;

    path = 'images/png/';
    patheps = 'images/eps/';
    pathew_eps = 'images/ew_eps/';
    file1= sprintf('drive-q%3.1f-m',q);
    file2= sprintf('-nuf%02d',nuf);
    ext = '.png';
    cnt = 1;
    clear ewarr;
    for m=[2 4 8 10 12 20 30]

        method = 'GEN_EIG';
        %----------------------------------------------------%
        res = drive1(m,tau,nuf,q,dographics,noiseperc,method);
        %----------------------------------------------------%
        y_1 = res.y_1;
        g_m = res.g_m;
        t0 = res.t0;
        gen = SFA_STRUCTS{res.hdl};
        disp(sprintf('%s: <y_1>=%7.2e, std(y_1)=%7.2e, eta(true,y_1)=%7.2f, %7.2f\n',...
                     method,mean(y_1),std(y_1),res.eta(1),res.eta(2)));

        % find the linear transformation [a b] which brings a*g_m(t)+b and y(t) in
        % optimal alignment: z = [a b] = X\y_1 is the vector which solves the 
        % linear system X*z = y_1 optimally in the LS sense.
        X = [g_m ones(size(g_m))]; 
        z=X\y_1; a=z(1); b=z(2);

        if dographics>=2
            figure(2);
            %set(gcf,'Position',[580,295,560,320]);
            if (m>8) 
                msz=4; pskip=2; 
            else
                msz=5; pskip=8;
            end
            subplot(2,1,1); plot(t0(1:pskip:end), y_1(1:pskip:end),'.b',...
                                 t0(1:pskip:end), a*g_m(1:pskip:end)+b,'-r',...
                                 'MarkerSize',msz,'LineWidth',1.0);
            % why '1:pskip:end'? - to make the PDF of the plot with pskip=2
            % somewhat smaller (360kB instead of 600kB). Default is pskip=1.
            title(['GEN\_EIG' ': output y_1(t) [blue], true driving force \gamma(t) [red]']); 
            ylabel('y_1(t)');
            %set(gca, 'YLim', [min(y_1),max(y_1)]*1.1);
            xlabel('t'); 
            set(gca,'FontSize',14);
        end

        ewarr(cnt,2)=numel(gen.DSF);    % number of eigenvalues GEN_EIG
        ewarr(cnt,4)=mean(res.y_1);
        ewarr(cnt,6)=std(res.y_1);
        ewarr(cnt,8)=res.eta(2);        % eta(y_1) for GEN_EIG

        method = 'SVD_SFA';
        %----------------------------------------------------%
        res = drive1(m,tau,nuf,q,dographics,noiseperc,method);
        %----------------------------------------------------%
        y_1 = res.y_1;
        g_m = res.g_m;
        g_S = res.g_S;
        t0 = res.t0;
        sfa = SFA_STRUCTS{res.hdl};
        disp(sprintf('%s: <y_1>=%7.2e, std(y_1)=%7.2e, eta(true,y_1)=%7.2f, %7.2f\n',...
                     method,mean(y_1),std(y_1),res.eta(1),res.eta(2)));

        % find the linear transformation [a b] which brings a*g_m(t)+b and y(t) in
        % optimal alignment: z = [a b] = X\y_1 is the vector which solves the 
        % linear system X*z = y_1 optimally in the LS sense.
        X = [g_m ones(size(g_m))]; 
        z=X\y_1; a=z(1); b=z(2);

        if dographics>=2
            figure(2);
            pskip=8;
            subplot(2,1,2); plot(t0(1:pskip:end), y_1(1:pskip:end),'.b',...
                                 t0(1:pskip:end), a*g_m(1:pskip:end)+b,'-r',...
                                 'MarkerSize',5,'LineWidth',1.3);
            % why '1:pskip:end'? - to make the PDF of the plot with pskip=2
            % somewhat smaller (360kB instead of 600kB). Default is pskip=1.
            title(['SVD\_SFA' ': output y_1(t) [blue], true driving force \gamma(t) [red]']); 
            ylabel('y_1(t)');
            %set(gca, 'YLim', [min(y_1),max(y_1)]*1.1);
            xlabel('t'); 
            text(90,-1.7,['m=' num2str(m)],'BackgroundColor',[1,0.9,0.6],'FontSize',12);
            set(gca,'FontSize',14);
        end

        if dographics>=2
            figure(3);
            semilogy(1:size(gen.DSF,1),gen.DSF,'-r',...
                     1:size(sfa.DSF,1),sfa.DSF,'.b',...
                     'LineWidth',1.7);
            ylabel('eigenvalues');
            xlabel('index');
            set(gca,'FontSize',14);
            legend({'GEN\_EIG','SVD\_SFA'},'Location','SouthEast','FontSize',14);
        end

        ewarr(cnt,1)=m;
        ewarr(cnt,3)=numel(sfa.DSF);    % number of eigenvalues SVD_SFA
        ewarr(cnt,5)=mean(res.y_1);
        ewarr(cnt,7)=std(res.y_1);
        ewarr(cnt,9)=res.eta(2);        % eta(y_1) for SVD_SFA
        ewarr(cnt,10)=sfa.rankB;        % rank of B    
        ewarr(cnt,11)=size(sfa.BD,1);   % size of B
        cnt = cnt+1;

        file = sprintf('%s%s%02d%s%s%s',path,file1,m,file2,ext);
        print('-f2', '-dpng', '-r100', file);
        file = sprintf('%s%s%02d%s%s%s',patheps,file1,m,file2,'.eps');
        print('-f2', '-depsc2', '-r100', file);
        file = sprintf('%s%s%02d%s%s%s',pathew_eps,file1,m,file2,'.eps');
        print('-f3', '-depsc2', '-r100', file);
        disp(sprintf('m=%d\n',m));  
    end
    %
    % The results for tables tab:GENvsSVD are in array ewarr.
    % Open ewarr in the Array Editor and copy-paste its contents to LaTeX.
    %
    res.ewarr = ewarr;
end