function [confmat,classerr] = mk_confmat(allrealclass,allcvpredict,nclass)
% mk_confmat: calculate confusion matrix
%
% INPUT
%   allrealclass    the real class labels for a set of records
%   allcvpredict    the predicted class labels for the same sets
%   nclass          number of classes
%
% OUTPUT
%   confmat     nclass x nclass matrix, where the columns are the true
%               class labels, the rows the predicted ones
%   classerr    nclass+1 row vector, the error ratio for each true class
%               plus the total error rate 
%
% Author: Wolfgang Konen, Nov 2009
%
% See also: CLASS_DEMO2, CLASS_CVDEMO2

    confmat = zeros(nclass,nclass);
    for i=1:nclass  % column i: real class i
        idx = find(allrealclass==i);
        for j=1:nclass  % row j: predicted class j
            confmat(j,i)=numel(find(allcvpredict(idx)==j));
        end
    end
    total = sum(confmat);
    t_err = sum(confmat-diag(diag(confmat)));
    classerr = t_err./(total+1e-15);
    % why '+1e-15'? - regularize the case where a certain class does not
    % appear at all in the test set
    totalerr = sum(t_err)/sum(total);
    classerr = [classerr totalerr];
end
  